pub struct TransactionLog {
pub to: String,
pub from: String,
pub amount: u32,
pub time: i64,
}Expand description
Struct that describes the format of the logs returned by
get_logs.
Fields
to: StringThe account to which the funds were sent to.
from: StringThe account from which the funds were sent from.
amount: u32The amount of CSH that was sent.
time: i64The time that the funds were sent in Unix epoch time.